@@ -33,14 +33,18 @@ class ReliableQueue:
         """
         sleep_time = 1
         accumulated_sleep_time = 0
+        have_warned = False
 
         while accumulated_sleep_time <= self.timeout_push:
             try:
                 self._redis.rpush(self._queue_name, data)
+                if have_warned:
+                    logger.info("ReliableQueue.push() redis is back")
                 break
             except ConnectionError as ex:
                 if (accumulated_sleep_time + sleep_time) <= self.timeout_push:
-                    logger.warning("ReliableQueue: Push failed: [" + str(ex) + "]" +
+                    have_warned = True
+                    logger.warning("ReliableQueue.push() Failed: [" + str(ex) + "]" +
                                    " sleeping " + str(sleep_time) + "s and then retrying. err=" + str(ex))
                     # FIXME What do we do if shutdown has been requested?
                     time.sleep(sleep_time)
@@ -66,11 +70,13 @@ class ReliableQueue:
                 if self._shutdown:
                     return None
                 result = self._redis.blpop(self._queue_name, 1)
+                if have_warned:
+                    logger.info("ReliableQueue.blocking_pop() redis is back")
                 if result is not None:
                     return result[1]
             except ConnectionError as ex:
                 if not have_warned:
-                    logger.error("Redis is down. Unable to pull. err=" + str(ex))
+                    logger.error("ReliableQueue.blocking_pop() Redis is down. Unable to pull. err=" + str(ex))
                     have_warned = True
             timeout -= 1
             time.sleep(1)
@@ -80,7 +86,10 @@ class ReliableQueue:
         have_warned = False
         while True:
             try:
-                return not self._redis.exists(self._queue_name)
+                result = not self._redis.exists(self._queue_name)
+                if have_warned:
+                    logger.info("ReliableQueue.is_ram_empty() redis is back.")
+                return result
             except ConnectionError as ex:
                 if not have_warned:
                     logger.error("ReliableQueue.is_ram_empty() redis problems. err=" + str(ex))
